Changelog
=========


0.0.6 (2019-11-16)
------------------
- Improved upload script to handle also testing. [atterdag]


0.0.5 (2019-11-16)
------------------
- Got rid of all the _query_ stuff in the various descriptions. This
  filter only reads, and writes LDIF. [atterdag]
- Renamed ansible playbook 'play.yml' to 'playbook.yml' to make it more
  clear how to run it. [atterdag]
- Improved name of task in example playbook. [atterdag]


0.0.4 (2019-11-16)
------------------
- I kinda broke my setup.py so it didn't include the actual python code.
  [atterdag]


0.0.3 (2019-11-16)
------------------
- First travis pipeline. [atterdag]
- Replaced jenkins with travis build status icon. [atterdag]
- Forgot to add ```dist/*``` as argument for twine check. [atterdag]


0.0.2 (2019-11-15)
------------------
- 2nd attempt tp upload. [atterdag]
- Fixed formatting errors in README.rst. [Valdemar Lemche]
- Initial version of module, and files to support pushing code to pipy.
  [atterdag]


0.0.1 (2019-11-15)
------------------
- Initial Commit [Valdemar Lemche]
